import { LoginOutlined } from "@ant-design/icons";
import { Button, Form, Modal, Tabs, notification } from "antd";
import {
  EncodeStringToBase64,
  myFetch,
  setUserSessionToLocalStorage,
  showInputsInvalidNotification,
} from "../../utils";
import { useState } from "react";
import {
  MyAccountNameFormInput,
  MyPasswordFormInput,
  MyUsernameFormInput,
} from "../../Components/MyFormInputs";
import { useTranslation } from "react-i18next";
import MyAppLogo from "../../Components/MyAppLogo";

export default function Login() {
  const { t, i18n } = useTranslation();
  const [form] = Form.useForm();

  const [notificationApi, notificationContextHolder] =
    notification.useNotification();

  const [selectedMethod, setSelectedMethod] = useState("1");
  const [isRequesting, setIsRequesting] = useState(false);

  const showErrorNotification = (errStatus) => {
    if (errStatus === 400) {
      notificationApi["error"]({
        message: t("login.request.400.title"),
        description: t("login.request.400.description"),
      });
    }
  };

  return (
    <>
      {notificationContextHolder}
      <Modal
        open={true}
        mask={false}
        closable={false}
        centered
        keyboard={false}
        footer={
          <Button
            type="primary"
            htmlType="submit"
            icon={<LoginOutlined />}
            loading={isRequesting}
            onClick={() => {
              form
                .validateFields()
                .then((values) => {
                  setIsRequesting(true);

                  let body = {
                    accountName: values.accountName.toLocaleLowerCase(),
                    password: EncodeStringToBase64(values.password),
                  };

                  if (selectedMethod === "2") {
                    body.username = values.username;
                    body.language = i18n.language;
                  }

                  myFetch({
                    url: `/user/auth/${
                      selectedMethod === "1" ? "login" : "signup"
                    }`,
                    method: "POST",
                    body: body,
                    notificationApi: notificationApi,
                    t: t,
                  })
                    .then((data) => {
                      setUserSessionToLocalStorage(data.XAuthorization);
                      window.location.href = "/";
                    })
                    .catch((errStatus) => {
                      showErrorNotification(errStatus);
                      setIsRequesting(false);
                    });
                })
                .catch(() => showInputsInvalidNotification(notificationApi, t));
            }}
          >
            {selectedMethod === "1" ? t("login.login") : t("login.signUp")}
          </Button>
        }
      >
        <div
          style={{
            display: "flex",
            justifyContent: "center",
          }}
        >
          <MyAppLogo height={80} />
        </div>

        <Tabs
          defaultActiveKey="1"
          items={[
            {
              key: "1",
              label: t("login.login"),
            },
            {
              key: "2",
              label: t("login.signUp"),
            },
          ]}
          centered
          onChange={(activeKey) => setSelectedMethod(activeKey)}
        />

        <Form form={form} layout="vertical" requiredMark={false}>
          {selectedMethod === "2" && <MyUsernameFormInput />}

          <MyAccountNameFormInput
            disableAccountNameCheck={selectedMethod === "1"}
            hasFeedback={selectedMethod === "2"}
          />

          <MyPasswordFormInput />
        </Form>
      </Modal>
    </>
  );
}
